@@ -1,4 +1,5 @@
 """Utilities for configuring ansible runtime environment."""
+import json
 import logging
 import os
 import pathlib
@@ -6,8 +7,9 @@ import re
 import subprocess
 import sys
 from functools import lru_cache
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
+import packaging
 import tenacity
 from packaging import version
 
@@ -95,6 +97,35 @@ def check_ansible_presence(exit_on_error: bool = False) -> Tuple[str, str]:
     return ver, err
 
 
+def install_collection(collection: str, destination: Optional[str] = None) -> None:
+    """Install an Ansible collection.
+
+    Can accept version constraints like 'foo.bar:>=1.2.3'
+    """
+    cmd = [
+        "ansible-galaxy",
+        "collection",
+        "install",
+        "--force",  # required for ansible 2.9
+        "-v",
+    ]
+    if destination:
+        cmd.extend(["-p", destination])
+    cmd.append(f"{collection}")
+
+    _logger.info("Running %s", " ".join(cmd))
+    run = subprocess.run(
+        cmd,
+        universal_newlines=True,
+        check=False,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.STDOUT,
+    )
+    if run.returncode != 0:
+        _logger.error("Command returned %s code:\n%s", run.returncode, run.stdout)
+        sys.exit(INVALID_PREREQUISITES_RC)
+
+
 @tenacity.retry(  # Retry up to 3 times as galaxy server can return errors
     reraise=True,
     wait=tenacity.wait_fixed(30),  # type: ignore
@@ -110,6 +141,7 @@ def install_requirements(requirement: str) -> None:
         "ansible-galaxy",
         "role",
         "install",
+        "--force",  # required for ansible 2.9
         "--roles-path",
         f"{options.cache_dir}/roles",
         "-vr",
@@ -135,6 +167,7 @@ def install_requirements(requirement: str) -> None:
             "ansible-galaxy",
             "collection",
             "install",
+            "--force",  # required for ansible 2.9
             "-p",
             f"{options.cache_dir}/collections",
             "-vr",
@@ -154,7 +187,7 @@ def install_requirements(requirement: str) -> None:
             raise RuntimeError(run.returncode)
 
 
-def prepare_environment() -> None:
+def prepare_environment(required_collections: Optional[Dict[str, str]] = None) -> None:
     """Make dependencies available if needed."""
     if not options.configured:
         # Allow method to be used without calling the command line, so we can
@@ -169,6 +202,15 @@ def prepare_environment() -> None:
         for req in pathlib.Path(".").glob("molecule/*/requirements.yml"):
             install_requirements(str(req))
 
+    if required_collections:
+        for name, min_version in required_collections.items():
+            install_collection(
+                f"{name}:>={min_version}",
+                destination=f"{options.cache_dir}/collections"
+                if options.cache_dir
+                else None,
+            )
+
     _install_galaxy_role()
     _perform_mockings()
     _prepare_ansible_paths()
@@ -185,6 +227,8 @@ def _get_galaxy_role_ns(galaxy_infos: Dict[str, Any]) -> str:
         role_namespace = ""
     else:
         role_namespace = f"{role_namespace}."
+    if not isinstance(role_namespace, str):
+        raise RuntimeError("Role namespace must be string, not %s" % role_namespace)
     return role_namespace
 
 
@@ -251,7 +295,7 @@ As an alternative, you can add 'role-name' to either skip_list or warn_list.
     # despite documentation stating that is_file() reports true for symlinks,
     # it appears that is_dir() reports true instead, so we rely on exits().
     target = pathlib.Path(options.project_dir).absolute()
-    if not link_path.exists() or os.readlink(link_path) != target:
+    if not link_path.exists() or os.readlink(link_path) != str(target):
         if link_path.exists():
             link_path.unlink()
         link_path.symlink_to(target, target_is_directory=True)
@@ -280,6 +324,12 @@ def _prepare_ansible_paths() -> None:
     _update_env(ansible_collections_path(), collection_list)
     _update_env('ANSIBLE_ROLES_PATH', roles_path, default=ANSIBLE_DEFAULT_ROLES_PATH)
 
+    # If we are asking to run without warnings, then also silence certain
+    # Ansible warnings which could slip through, namely the devel branch
+    # warning.
+    if options.verbosity < 0:
+        _update_env("ANSIBLE_DEVEL_WARNING", ["False"])
+
 
 def _make_module_stub(module_name: str) -> None:
     # a.b.c is treated a collection
@@ -369,3 +419,93 @@ def _perform_mockings() -> None:
         if link_path.exists():
             link_path.unlink()
         link_path.symlink_to(target, target_is_directory=True)
+
+
+def ansible_config_get(key: str, kind: Type[Any] = str) -> Union[str, List[str], None]:
+    """Return configuration item from ansible config."""
+    env = os.environ.copy()
+    # Avoid possible ANSI garbage
+    env["ANSIBLE_FORCE_COLOR"] = "0"
+    # Avoid our own override as this prevents returning system paths.
+    colpathvar = ansible_collections_path()
+    if colpathvar in env:
+        env.pop(colpathvar)
+
+    config = subprocess.check_output(
+        ["ansible-config", "dump"], universal_newlines=True, env=env
+    )
+
+    if kind == str:
+        result = re.search(rf"^{key}.* = (.*)$", config, re.MULTILINE)
+        if result:
+            return result.groups()[0]
+    elif kind == list:
+        result = re.search(rf"^{key}.* = (\[.*\])$", config, re.MULTILINE)
+        if result:
+            val = eval(result.groups()[0])  # pylint: disable=eval-used
+            if not isinstance(val, list):
+                raise RuntimeError(f"Unexpected data read for {key}: {val}")
+            return val
+    else:
+        raise RuntimeError("Unknown data type.")
+    return None
+
+
+def require_collection(  # noqa: C901
+    name: str, version: Optional[str] = None, install: bool = True
+) -> None:
+    """Check if a minimal collection version is present or exits.
+
+    In the future this method may attempt to install a missing or outdated
+    collection before failing.
+    """
+    try:
+        ns, coll = name.split('.', 1)
+    except ValueError:
+        sys.exit("Invalid collection name supplied: %s" % name)
+
+    paths = ansible_config_get('COLLECTIONS_PATHS', list)
+    if not paths or not isinstance(paths, list):
+        sys.exit(f"Unable to determine ansible collection paths. ({paths})")
+
+    if options.cache_dir:
+        # if we have a cache dir, we want to be use that would be preferred
+        # destination when installing a missing collection
+        paths.insert(0, f"{options.cache_dir}/collections")
+
+    for path in paths:
+        collpath = os.path.join(path, 'ansible_collections', ns, coll)
+        if os.path.exists(collpath):
+            mpath = os.path.join(collpath, 'MANIFEST.json')
+            if not os.path.exists(mpath):
+                _logger.fatal(
+                    "Found collection at '%s' but missing MANIFEST.json, cannot get info.",
+                    collpath,
+                )
+                sys.exit(INVALID_PREREQUISITES_RC)
+
+            with open(mpath, 'r') as f:
+                manifest = json.loads(f.read())
+                found_version = packaging.version.parse(
+                    manifest['collection_info']['version']
+                )
+                if version and found_version < packaging.version.parse(version):
+                    if install:
+                        install_collection(f"{name}:>={version}")
+                        require_collection(name, version, install=False)
+                    else:
+                        _logger.fatal(
+                            "Found %s collection %s but %s or newer is required.",
+                            name,
+                            found_version,
+                            version,
+                        )
+                        sys.exit(INVALID_PREREQUISITES_RC)
+            break
+    else:
+        if install:
+            install_collection(f"{name}:>={version}")
+            require_collection(name, version, install=False)
+        else:
+            _logger.fatal("Collection '%s' not found in '%s'", name, paths)
+            sys.exit(INVALID_PREREQUISITES_RC)
