@@ -1,8 +1,9 @@
 """Test ability to import playbooks."""
+from ansiblelint.rules import RulesCollection
 from ansiblelint.runner import Runner
 
 
-def test_task_hook_import_playbook(default_rules_collection):
+def test_task_hook_import_playbook(default_rules_collection: RulesCollection) -> None:
     """Assures import_playbook includes are recognized."""
     playbook_path = 'examples/playbooks/playbook-parent.yml'
     runner = Runner(playbook_path, rules=default_rules_collection)
