@@ -9,16 +9,16 @@ from ansiblelint.runner import Runner
 class TestTaskHasNameRule(unittest.TestCase):
     collection = RulesCollection()
 
-    def setUp(self):
+    def setUp(self) -> None:
         self.collection.register(TaskHasNameRule())
 
-    def test_file_positive(self):
+    def test_file_positive(self) -> None:
         success = 'examples/playbooks/task-has-name-success.yml'
         good_runner = Runner(success, rules=self.collection)
-        self.assertEqual([], good_runner.run())
+        assert [] == good_runner.run()
 
-    def test_file_negative(self):
+    def test_file_negative(self) -> None:
         failure = 'examples/playbooks/task-has-name-failure.yml'
         bad_runner = Runner(failure, rules=self.collection)
         errs = bad_runner.run()
-        self.assertEqual(4, len(errs))
+        assert len(errs) == 4
